@@ -22,7 +22,13 @@ from .object_utils import (
     load_obj,
 )
 from .material_utils import set_inst_material, load_hdri_world, build_tex
-from .render_utils import set_image_render, set_annotation_render, render_data
+from .render_utils import (
+    set_cycles_compute_device_type,
+    set_image_render,
+    set_annotation_render,
+    render_image,
+    render_data,
+)
 from .pose_utils import get_6d_pose
 from .scene_setting import (
     set_cam_pose,
@@ -33,3 +39,4 @@ from .scene_setting import (
     add_stage,
 )
 from .physic_utils import set_origin_and_record_old_v0
+from .domain_randomzition import texture_bsdf_dr, load_distractor
