@@ -7,26 +7,41 @@ Created on Sat Dec 28 21:33:28 2019
 """
 
 from boxx import *
-from boxx import os, pathjoin, withattr, imread, sysi
+from boxx import os, withattr, imread
 
 import bpy
-import time
 import tempfile
 from collections import OrderedDict
 
-from .select_utils import scene, render
 from .statu_recover import StatuRecover, undo
 from .exr_image_parser import parser_exr, ImageWithAnnotation
 from .material_utils import set_inst_material
 from .pose_utils import get_6d_pose
 
 
+def set_cycles_compute_device_type(compute_device_type="CUDA"):
+    bpy.context.scene.cycles.device = "GPU"
+    bpy.context.preferences.addons[
+        "cycles"
+    ].preferences.compute_device_type = compute_device_type
+    bpy.context.preferences.addons["cycles"].preferences.get_devices()
+    print(
+        "compute_device_type =",
+        bpy.context.preferences.addons["cycles"].preferences.compute_device_type,
+    )
+    for d in bpy.context.preferences.addons["cycles"].preferences.devices:
+        d["use"] = True
+        print(d["name"], d["use"])
+
+
 class set_annotation_render(StatuRecover):
     def __init__(self):
         StatuRecover.__init__(self)
         # TODO detect whether in ssh X11 forward
         # if sysi.gui:  # mean "does the enviroment support GUI".
         # self.set_attr(render, "engine", "BLENDER_EEVEE")
+        scene = bpy.data.scenes[0]
+        render = scene.render
         if render.engine == "BLENDER_WORKBENCH":
             self.set_attr(render, "engine", "CYCLES")
         if render.engine == "BLENDER_EEVEE":
@@ -57,33 +72,39 @@ class set_annotation_render(StatuRecover):
 class set_image_render(StatuRecover):
     def __init__(self):
         StatuRecover.__init__(self)
-        # self.set_attr(render, "engine", "BLENDER_EEVEE" if eevee else "CYCLES")
-        # self.set_attr(scene.cycles, "samples", 128)
+        scene = bpy.data.scenes[0]
+        render = scene.render
         attrs = dict(file_format="PNG", compression=15)
         self.set_attrs(render.image_settings, attrs)
-        # render.image_settings.file_format = 'JPEG'
-        # render.image_settings.quality = 100
 
 
+def render_image():
+    render = bpy.data.scenes[0].render
+    png_path = tempfile.NamedTemporaryFile().name + ".png"
+    with set_image_render(), withattr(render, "filepath", png_path):
+        print("Render image using:", render.engine)
+        bpy.ops.render.render(write_still=True)
+    image = imread(png_path)[..., :3]
+    os.remove(png_path)
+    return image
+
+
+_render_image = render_image
 befor_render_data_hooks = OrderedDict()
 
 # @undo()
 def render_data(render_image=True, render_annotation=True):
+    scene = bpy.data.scenes[0]
+    render = scene.render
     for hook_name, hook in befor_render_data_hooks.items():
         print(f"Run befor_render_data_hooks[{hook_name}]")
         hook()
     befor_render_data_hooks.clear()
 
-    path = pathjoin(tempfile.gettempdir(), "render_" + str(time.time()))
+    path = tempfile.NamedTemporaryFile().name
     render_result = {}
     if render_image:
-        png_path = path + ".png"
-        with set_image_render(), withattr(render, "filepath", png_path):
-            print("Render image using:", render.engine)
-            bpy.ops.render.render(write_still=True)
-        render_result["image"] = imread(png_path)[..., :3]
-        os.remove(png_path)
-
+        render_result["image"] = _render_image()
     if render_annotation:
         exr_path = path + ".exr"
         with set_inst_material(), set_annotation_render(), withattr(
@@ -94,7 +115,7 @@ def render_data(render_image=True, render_annotation=True):
         render_result["exr"] = parser_exr(exr_path)
         os.remove(exr_path)
     result = ImageWithAnnotation(**render_result)
-    if "render_6d_pose":
+    if "render_6d_pose" and render_annotation:
         objs = [obj for obj in bpy.data.objects if "inst_id" in obj]
         ycb_6d_pose = get_6d_pose(objs, inst=result["inst"])
         result["ycb_6d_pose"] = ycb_6d_pose
